Parsing and type enforcement for XML serialization (sarpy.io.xml.descriptors)
=============================================================================

.. automodule:: sarpy.io.xml.descriptors
    :members:
    :show-inheritance:
    :inherited-members:
